@@ -5,7 +5,18 @@
 #include<Rinternals.h>
 #include<R_ext/Rdynload.h>
 
-/* .C calls */
+extern void SmoothEWS( 
+	double *pData, 		//TxN matrix (vectorized) containing data to smooth
+	int *pT, 		//Length of periodogram to smooth
+	int *pN, 		//Number of periodograms to smooth
+	int *pM, 		//Bandwidth parameter (# of weights either side of the centre)
+	double *pWts, 		//Smoothing kernel weights
+	int *pContribute,	//Vector length N: 1 -> calculate score, otherwise -> don't 
+	double *pEps, 		//Tolerance to apply to smoothed periodogram
+	double *pScore, 	//RETURN: GCV-score
+	int *pErr 		//RETURN: error code
+		);
+
 void PsiJl(
 	double *ppsi, 	//Wavelet function vector
 	int *pL, 	//Length of ppsi
@@ -30,6 +41,14 @@ void PsiJL(
 	int *pErr	//RETURN: Error code
 		);
 
+extern  void AutoCorr(
+	double *ppsi, 	//Wavelet function vector
+	int *pL, 	//Length of ppsi
+	int *pJ, 	//Number of levels
+	double *pPsiJL, //RETURN: Wavelet AutoCor fn at all levels
+	int *pErr	//RETURN: Error Code
+		);
+
 void A_lam_jlh(
 	double *pPsi_jl,	//Wavelet autocorrelation between levels j & l
 	int *pminjl,		//Location of lowest non-0 in pPsi_jl
@@ -41,6 +60,29 @@ void A_lam_jlh(
 	double *pA		//RETURN: Wavelet autocorr inner product, A^{\lambda}_{j,l,h}
 		);
 		
+extern  void WaveCorrInnerProd(
+	double *pPsi,		//Wavelet autocorrelation values (vectorized (2L+1)xJxJ array)
+	int *pmin,		//Length J index vector place of lowest non-0 in pPsi per level pair
+	int *pmax,		//Length J index vector place of higher non-0 in pPsi per level pair
+	int *pL,		//2L+1 is the length of the vector pPsi_jl
+	int *pJ,		//Number of levels
+	double *pWACIP,		//RETURN: Wave. AutoCor. Inner Prod. (vectorized (2L+1)xJxJxJ array)
+	int *pErr		//RETURN: error code
+		);
+
+extern  void SmoothCovEst(
+	double *pSpq,		//Wavelet cross spectrum between series p&q (vectorized TxJ matix)
+	double *pSpp,		//Wavelet spectrum of series p (vectorized TxJ matix)
+	double *pSqq,		//Wavelet spectrum of series q (vectorized TxJ matix)
+	double *pWACIP,		//Wavelet AutoCorr. Inner Product (vectorizd (2T+1)xJxJxJ array)
+	int *pJ,		//Number of levels
+	int *pT,		//Time series length
+	int *pM,		//Smooth kernel bandwidth parameter
+	double *pWts,		//Smoothing kernel weights
+	double *pSmoothCov,	//RETURN: Smoothed covariance matrices (vectorized TxJxJ array)
+	int *pErr		//RETURN: Error code
+		);
+	
 void E_dpjk_dqlm(
 	double *pSpec,	//Wavelet (Cross-) Spectrum
 	double *pWACIP,	//Wavelet Autocorrelation Inner Product
@@ -706,20 +748,25 @@ static R_NativePrimitiveArgType WaveCorrInnerProd_t[] = {
 static R_NativePrimitiveArgType SmoothCovEst_t[] = {
   REALSXP,REALSXP,REALSXP,REALSXP,INTSXP,INTSXP,INTSXP,REALSXP,REALSXP,INTSXP
 };
-*/
 
+static R_CMethodDef cMethods[] = {
+  {"SmoothEWS", (DL_FUNC) &SmoothEWS, 9, SmoothEWS_t},
+  {"AutoCorr", (DL_FUNC) &AutoCorr, 5, AutoCorr_t},
+  {"WaveCorrInnerProd", (DL_FUNC) &WaveCorrInnerProd, 7, WaveCorrInnerProd_t},
+  {"SmoothCovEst", (DL_FUNC) &SmoothCovEst, 10, SmoothCovEst_t},
+  {NULL,NULL,0}
+};*/
 
-static const R_CMethodDef CEntries[] = {
-    {"AutoCorr",          (DL_FUNC) &AutoCorr,           5},
-    {"SmoothCovEst",      (DL_FUNC) &SmoothCovEst,      10},
-    {"SmoothEWS",         (DL_FUNC) &SmoothEWS,          9},
-    {"WaveCorrInnerProd", (DL_FUNC) &WaveCorrInnerProd,  7},
-    {NULL, NULL, 0}
-};
-
-void R_init_mvLSW(DllInfo *dll)
-{
-    R_registerRoutines(dll, CEntries, NULL, NULL, NULL);
-    R_useDynamicSymbols(dll, FALSE);
+void R_init_mvLSW_Cfunctions(DllInfo *info){
+     
+    R_CMethodDef cMethods[] = {
+        {"SmoothEWS", (DL_FUNC) &SmoothEWS, 9},
+        {"AutoCorr", (DL_FUNC) &AutoCorr, 5},
+        {"WaveCorrInnerProd", (DL_FUNC) &WaveCorrInnerProd, 7},
+        {"SmoothCovEst", (DL_FUNC) &SmoothCovEst, 10},
+        {NULL,NULL,0}
+    };
+    
+    R_registerRoutines(info, cMethods, NULL, NULL, NULL);
+    R_useDynamicSymbols(info, TRUE);
 }
-
